# scann2dxf

simple python based scann to dxf converter

* early alpha state - works for me :)
* input from image
* input direct from scanner
* auto rotate

## quikstart

### install with pip
```
pip3 install scann2dxf
```

### get code
```
git clone git@github.com:multigcs/scann2dxf.git
cd scann2dxf
pip3 install -r requirements.txt
```

### scann2dxf example
```
scann2dxf -i input.png -o scann.dxf
```

![image](https://raw.githubusercontent.com/multigcs/scann2dxf/main/docs/image.png)
![dxf](https://raw.githubusercontent.com/multigcs/scann2dxf/main/docs/dxf.png)
